======================
beproud.django.commons
======================

Common utilities for Django A.K.A. bpcommons.

See the docs at: http://bpcommons.rtfd.io/

Run tests using tox::

    $ tox

Supports
========
- Python: 3.10, 3.11, 3.12, 3.13, 3.14
- Django: 4.2, 5.2

Links
=====

- `PyPI <https://pypi.python.org/pypi/beproud.django.commons>`__
- `Documentation <http://bpcommons.rtfd.io/>`__
- `Repository <https://github.com/beproud/bpcommons/>`__

LICENSE
=======

BSD License.

